==> advanced-react-scripts-0.2.1.tgz: package/config/advanced-react-scripts/customizers/webpack-loaders.js <==
const styleLoader = require('../config/styles-loader');
const sassLoader = require.resolve('sass-loader');


// Allows you to use two kinds of imports for SVG:
// import logoUrl from './logo.svg'; gives you the URL.
// import { ReactComponent as Logo } from './logo.svg'; gives you a component.
const svgLoader = isDev => {
    return {
            test: /\.svg$/,
            use: [
            {
                loader: require.resolve('babel-loader'),
                options: {
                    // @remove-on-eject-begin
                    babelrc: false,
                    presets: [require.resolve('babel-preset-react-app')],
                    // @remove-on-eject-end
                    cacheDirectory: true,
                }
            },
            require.resolve('svgr/webpack'),
            {
                loader: require.resolve('file-loader'),
                options: {
                    name: 'static/media/[name].[hash:8].[ext]',
                }
            }
        ]
    }
};

module.exports = {
    CSS: {
        default: true,
        get: styleLoader(undefined, /\.css$/, /\.module\.css$/),
    },
    CSS_MODULES: {
        get: styleLoader(undefined, /\.module\.css$/, undefined, true),
    },
    SASS: {
        get: styleLoader(sassLoader, /\.s[ac]ss$/, /\.module\.s[ac]ss$/),
    },
    SASS_MODULES: {
        get: styleLoader(sassLoader, /\.module\.s[ac]ss$/, undefined, true),
    },
    SVG: {
        default: true,
        get: svgLoader
    },
};

==> advanced-react-scripts-0.2.7.tgz: package/config/advanced-react-scripts/customizers/webpack-loaders.js <==
const styleLoader = require('../config/styles-loader');
const sassLoader = require.resolve('sass-loader');


// Allows you to use two kinds of imports for SVG:
// import logoUrl from './logo.svg'; gives you the URL.
// import { ReactComponent as Logo } from './logo.svg'; gives you a component.
const svgLoader = isDev => {
    return {
            test: /\.svg$/,
            use: [
            {
                loader: require.resolve('babel-loader'),
                options: {
                    // @remove-on-eject-begin
                    babelrc: false,
                    presets: [require.resolve('babel-preset-react-app-fresh')],
                    // @remove-on-eject-end
                    cacheDirectory: true,
                }
            },
            require.resolve('svgr/webpack'),
            {
                loader: require.resolve('file-loader'),
                options: {
                    name: 'static/media/[name].[hash:8].[ext]',
                }
            }
        ]
    }
};

module.exports = {
    CSS: {
        default: true,
        get: styleLoader(undefined, /\.css$/, /\.module\.css$/),
    },
    CSS_MODULES: {
        get: styleLoader(undefined, /\.module\.css$/, undefined, true),
    },
    SASS: {
        get: styleLoader(sassLoader, /\.s[ac]ss$/, /\.module\.s[ac]ss$/),
    },
    SASS_MODULES: {
        get: styleLoader(sassLoader, /\.module\.s[ac]ss$/, undefined, true),
    },
    SVG: {
        default: true,
        get: svgLoader
    },
};
